==> applet-service-1.0.2-20190123.061835-9-sources.jar: com/bizvane/appletservice/models/bo/WxInterfaceActivateBO.java <==
package com.bizvane.appletservice.models.bo;

/**
 * @ClassName WxInterfaceActivateBO
 * @DescriptTion :会员卡接口激活
 * @Auther: wd
 * @Date :2018/12/28 9:57
 */
public class WxInterfaceActivateBO {

    /**
     * init_bonus : 100
     * init_bonus_record : 旧积分同步
     * init_balance : 200
     * membership_number : AAA00000001
     * code : 12312313
     * card_id : xxxx_card_id
     * background_pic_url : https://mmbiz.qlogo.cn/mmbiz/0?wx_fmt=jpeg
     * init_custom_field_value1 : xxxxx
     */
    private Long sysBrandId;
    private Integer init_bonus;
    private String init_bonus_record;
    private Integer init_balance;
    private String membership_number;
    private String code;
    private String card_id;
    private String background_pic_url;
    private String init_custom_field_value1;
    private String init_custom_field_value2;
    private String init_custom_field_value3;

    public String getInit_custom_field_value2() {
        return init_custom_field_value2;
    }

    public void setInit_custom_field_value2(String init_custom_field_value2) {
        this.init_custom_field_value2 = init_custom_field_value2;
    }

    public String getInit_custom_field_value3() {
        return init_custom_field_value3;
    }

    public void setInit_custom_field_value3(String init_custom_field_value3) {
        this.init_custom_field_value3 = init_custom_field_value3;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public Integer getInit_bonus() {
        return init_bonus;
    }

    public void setInit_bonus(Integer init_bonus) {
        this.init_bonus = init_bonus;
    }

    public String getInit_bonus_record() {
        return init_bonus_record;
    }

    public void setInit_bonus_record(String init_bonus_record) {
        this.init_bonus_record = init_bonus_record;
    }

    public Integer getInit_balance() {
        return init_balance;
    }

    public void setInit_balance(Integer init_balance) {
        this.init_balance = init_balance;
    }

    public String getMembership_number() {
        return membership_number;
    }

    public void setMembership_number(String membership_number) {
        this.membership_number = membership_number;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getCard_id() {
        return card_id;
    }

    public void setCard_id(String card_id) {
        this.card_id = card_id;
    }

    public String getBackground_pic_url() {
        return background_pic_url;
    }

    public void setBackground_pic_url(String background_pic_url) {
        this.background_pic_url = background_pic_url;
    }

    public String getInit_custom_field_value1() {
        return init_custom_field_value1;
    }

    public void setInit_custom_field_value1(String init_custom_field_value1) {
        this.init_custom_field_value1 = init_custom_field_value1;
    }
}

==> applet-service-1.0.2-20190125.032911-19-sources.jar: com/bizvane/appletservice/models/bo/WxInterfaceActivateBO.java <==
package com.bizvane.appletservice.models.bo;

/**
 * @ClassName WxInterfaceActivateBO
 * @DescriptTion :会员卡接口激活
 * @Auther: wd
 * @Date :2018/12/28 9:57
 */
public class WxInterfaceActivateBO {

    /**
     * init_bonus : 100
     * init_bonus_record : 旧积分同步
     * init_balance : 200
     * membership_number : AAA00000001
     * code : 12312313
     * card_id : xxxx_card_id
     * background_pic_url : https://mmbiz.qlogo.cn/mmbiz/0?wx_fmt=jpeg
     * init_custom_field_value1 : xxxxx
     */
    private Long sysBrandId;
    private Integer init_bonus;
    private String init_bonus_record;
    private Integer init_balance;
    private String membership_number;
    private String code;
    private String card_id;
    private String background_pic_url;
    private String init_custom_field_value1;
    private String init_custom_field_value2;
    private String init_custom_field_value3;

    public String getInit_custom_field_value2() {
        return init_custom_field_value2;
    }

    public void setInit_custom_field_value2(String init_custom_field_value2) {
        this.init_custom_field_value2 = init_custom_field_value2;
    }

    public String getInit_custom_field_value3() {
        return init_custom_field_value3;
    }

    public void setInit_custom_field_value3(String init_custom_field_value3) {
        this.init_custom_field_value3 = init_custom_field_value3;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public Integer getInit_bonus() {
        return init_bonus;
    }

    public void setInit_bonus(Integer init_bonus) {
        this.init_bonus = init_bonus;
    }

    public String getInit_bonus_record() {
        return init_bonus_record;
    }

    public void setInit_bonus_record(String init_bonus_record) {
        this.init_bonus_record = init_bonus_record;
    }

    public Integer getInit_balance() {
        return init_balance;
    }

    public void setInit_balance(Integer init_balance) {
        this.init_balance = init_balance;
    }

    public String getMembership_number() {
        return membership_number;
    }

    public void setMembership_number(String membership_number) {
        this.membership_number = membership_number;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getCard_id() {
        return card_id;
    }

    public void setCard_id(String card_id) {
        this.card_id = card_id;
    }

    public String getBackground_pic_url() {
        return background_pic_url;
    }

    public void setBackground_pic_url(String background_pic_url) {
        this.background_pic_url = background_pic_url;
    }

    public String getInit_custom_field_value1() {
        return init_custom_field_value1;
    }

    public void setInit_custom_field_value1(String init_custom_field_value1) {
        this.init_custom_field_value1 = init_custom_field_value1;
    }

    @Override
    public String toString() {
        return "WxInterfaceActivateBO{" +
                "sysBrandId=" + sysBrandId +
                ", init_bonus=" + init_bonus +
                ", init_bonus_record='" + init_bonus_record + '\'' +
                ", init_balance=" + init_balance +
                ", membership_number='" + membership_number + '\'' +
                ", code='" + code + '\'' +
                ", card_id='" + card_id + '\'' +
                ", background_pic_url='" + background_pic_url + '\'' +
                ", init_custom_field_value1='" + init_custom_field_value1 + '\'' +
                ", init_custom_field_value2='" + init_custom_field_value2 + '\'' +
                ", init_custom_field_value3='" + init_custom_field_value3 + '\'' +
                '}';
    }
}
